package
Version:
v0.7.1
Opens a new window with list of versions in this module.
Published: Apr 28, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
Decode decodes a reader, unmarshalls the bytes into the out interface as json
DecodeValidate decodes a reader, unmarshalls the bytes into the out interface as json, and validates it
Validate is a processor function that will validate an interface with a given validator
type Config struct {
Port int `envconfig:"PORT" default:"8080"`
Timeout time.Duration `envconfig:"TIMEOUT" default:"30s"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.